<?php
namespace App\Controller;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;

use App\Templates;
use App\Exception;

class OrderController {
    
    const FAILOVER_EMAIL = "delivery@teknisa.com";  

    private $integrationService;
    private $connection;
    private $util;
    
    public function __construct (\Doctrine\DBAL\Connection $connection,
                                 \App\Service\OrderService $orderService,
                                 \App\Util\Util $util) {

        $this->connection         = $connection;
        $this->orderService       = $orderService;
        $this->util               = $util;
    }
    
    public function welcome(Request $request, Response $response) {
        global $CLIENT_DATA;
        
        $config      = $CLIENT_DATA;
        $sql         = "SELECT CDFILIAL FROM FILIAL";
        $result      = $this->connection->fetchAll($sql);
        $versionInfo = $this->getVersionInfo();

        return $response->withJson([
            'client'       => $config['client'],
            'version'      => $versionInfo['version'],
            'revision'     => $versionInfo['revision'],
            'date'         => $versionInfo['date'],
            'filialCount'  => count($result)
        ]);
    }
    
    private function getVersionInfo() {
        $file = file_get_contents(__DIR__ . "/../../version.json");
        return json_decode($file, true);
    }
    
    public function getSales(Request $request, Response $response){
        $params  = $request->getParsedBody();
        
        
        try {
            
        if(!isset($params['subsidiaryCode']))
            throw new Exception\Exception("Filial não informada. Favor enviar na requisição o código da filial.");
        
        $sales = $this->orderService->getSales($params);
        return $response->withJson([$sales]);
        
        }catch (\Exception $e) {
            return $response->withJson([
                'success' => false,
                'message' => $e->getMessage(),
                'result'  => []
            ]); 
        }
        
    }
    
    public function getDayReduction(Request $request, Response $response){
         $params  = $request->getParsedBody();
        
        try {
            
        if(!isset($params['subsidiaryCode']))
            throw new Exception\Exception("Filial não informada. Favor enviar na requisição o código da filial.");
        
        $reductions = $this->orderService->getReduction($params);
        
        return $response->withJson([$reductions]);
        
        }catch (\Exception $e) {
            return $response->withJson([
                'success' => false,
                'message' => $e->getMessage(),
                'result'  => []
            ]); 
        }
        
    }
    
    public function getStock (Request $request, Response $response){
        $params  = $request->getParsedBody();
        
        try {
            
        if(!isset($params['subsidiaryCode']))
            throw new Exception\Exception("Filial não informada. Favor enviar na requisição o código da filial.");
        
        $stock = $this->orderService->getStockExit($params);
        return $response->withJson([$stock]);
        
        }catch (\Exception $e) {
            return $response->withJson([
                'success' => false,
                'message' => $e->getMessage(),
                'result'  => []
            ]); 
        }    
    }
    
}
